; *******************************************************************
; *** This software is copyright 2004 by Michael H Riley          ***
; *** You have permission to use, modify, copy, and distribute    ***
; *** this software so long as this copyright notice is retained. ***
; *** This software may not be used in commercial applications    ***
; *** without express written permission from the author.         ***
; *******************************************************************

include    bios.inc
include    kernel.inc

           org     8000h
           db      'TYPE',0
           dw      9000h
           dw      endrom+7000h
           dw      2000h
           dw      endrom-2000h
           dw      2000h
           db      0
 
           org     2000h
           br      start

include    date.inc

start:     ghi     ra                  ; copy argument address to rf
           phi     rf
           glo     ra
           plo     rf
loop1:     lda     rf                  ; look for first less <= space
           smi     33
           bdf     loop1
           dec     rf                  ; backup to char
           ldi     0                   ; need proper termination
           str     rf
           ghi     ra                  ; back to beginning of name
           phi     rf
           glo     ra
           plo     rf
           ldi     high fildes         ; get file descriptor
           phi     rd
           ldi     low fildes
           plo     rd
           ldi     0                   ; flags for open
           plo     r7
           sep     scall               ; attempt to open file
           dw      o_open
           bnf     opened              ; jump if file was opened
           ldi     high errmsg         ; get error message
           phi     rf
           ldi     low errmsg
           plo     rf
           sep     scall               ; display it
           dw      f_msg
           lbr     o_wrmboot           ; and return to os
opened:    ghi     rd                  ; make copy of descriptor
           phi     rb
           glo     rd
           plo     rb
           ldi     high buffer         ; buffer to rettrieve data
           phi     rf
           ldi     low buffer
           plo     rf

           ldi     0
           phi     r7
           plo     r7

mainlp:    ldi     0                   ; want to read 16 bytes
           phi     rc
           ldi     16
           plo     rc 
           ldi     high buffer         ; buffer to rettrieve data
           phi     rf
           ldi     low buffer
           plo     rf
           ghi     rb                  ; get descriptor
           phi     rd
           glo     rb
           plo     rd
           sep     scall               ; read the header
           dw      o_read
           glo     rc                  ; check for zero bytes read
           bz      done                ; jump if so
           ldi     high buffer         ; buffer to rettrieve data
           phi     r8
           ldi     low buffer
           plo     r8
linelp:    lda     r8                  ; get next byte
           sep     scall 
           dw      f_type
           dec     rc                  ; decrement read count
           glo     rc                  ; see if done
           bnz     linelp              ; loop back if not
           br      mainlp              ; and loop back til done

done:      sep     scall               ; close the file
           dw      o_close
           sep     sret                ; return to os




errmsg:    db      'File not found',10,13,0
fildes:    db      0,0,0,0
           dw      dta
           db      0,0
           db      0
           db      0,0,0,0
           dw      0,0
           db      0,0,0,0

endrom:    equ     $

buffer:    ds      20
cbuffer:   ds      80
dta:       ds      512

